package org.rti.rcp.tomcat;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.derby.drda.NetworkServerControl;
import org.apache.http.HttpException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.equinox.app.IApplication;
import org.eclipse.equinox.app.IApplicationContext;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.PlatformUI;
import org.rti.rcp.tomcat.utils.Bootstrap;
import org.rti.zcore.updates.UpdateApplication;
import org.rti.zcore.utils.Network;

/**
 * This class controls all aspects of the application's execution
 */
public class Application implements IApplication {

    /**
	 * Commons Logging instance.
	 */
	private static Log log = LogFactory.getFactory().getInstance(
			Application.class);
	public static NetworkServerControl server;

	/* (non-Javadoc)
	 * @see org.eclipse.equinox.app.IApplication#start(org.eclipse.equinox.app.IApplicationContext)
	 */
	public Object start(IApplicationContext context) throws Exception {
		// set catalina.home
		String catalinaHome = new File(".").getAbsolutePath().replace("app\\.", "");
		// when debugging, set path using zcoreCatalinaHome in Eclipse IDE.
		if (System.getenv("zcoreCatalinaHome") != null) {
			catalinaHome = System.getenv("zcoreCatalinaHome");
		}
		log.debug("catalina.home: " + catalinaHome);
		try {
			//File catalinaPath = new File(System.getProperty("user.dir"), "..");
			//System.setProperty("catalina.home",(catalinaPath).getCanonicalPath());
			System.setProperty("catalina.home",catalinaHome);
		} catch (Exception e) {
			// Ignore
			//System.setProperty("catalina.home", System.getProperty("user.dir"));
			log.debug("Error in setting catalina.home path: " +  catalinaHome + " Error: "+ e);
		}
		// Load networking to use system proxies.
		Network.setSystemProxy();
		//if ((Constants.UPDATES_DYNASITE != null) && (Constants.UPDATES_DYNASITE.equals("true"))) {
		log.debug("Processing Applicaton Updates");

		String message = null;
		try {
			message = UpdateApplication.execute();
			if (message == null) {
				log.debug("No updates.");
			}
		} catch (Exception e1) {
			e1.printStackTrace();
		}
		log.debug("Finished processing Applicaton Updates");

		Job job = new Job("Download Updates") {
			protected IStatus run(IProgressMonitor monitor) {
				try {
					UpdateApplication.downloadUpdates();
				} catch (FileNotFoundException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (HttpException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				} catch (IOException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
				return Status.OK_STATUS;
			}
		};
		job.setSystem(true);
		job.schedule();
		//}
		Bootstrap bootStrap = new Bootstrap();
		try {
			bootStrap.init();
			bootStrap.start();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			log.error(e);
			e.printStackTrace();
		}

		Display display = PlatformUI.createDisplay();
		try {
			int returnCode = PlatformUI.createAndRunWorkbench(display, new ApplicationWorkbenchAdvisor());
			if (returnCode == PlatformUI.RETURN_RESTART)
				return IApplication.EXIT_RESTART;
			else
				return IApplication.EXIT_OK;
		} finally {
			display.dispose();
		}

	}

	/* (non-Javadoc)
	 * @see org.eclipse.equinox.app.IApplication#stop()
	 */
	public void stop() {
/*
		// Grab the Scheduler instance from the Factory
        Scheduler scheduler;
		try {
			scheduler = StdSchedulerFactory.getDefaultScheduler();
	        // and start it off
	        scheduler.shutdown();
		} catch (SchedulerException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
*/

		try {
			server.shutdown();
		} catch (Exception e) {
			log.error(e);
		}
		Bootstrap bootStrap = new Bootstrap();
		try {
			bootStrap.stop();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		final IWorkbench workbench = PlatformUI.getWorkbench();
		if (workbench == null)
			return;
		final Display display = workbench.getDisplay();
		display.syncExec(new Runnable() {
			public void run() {
				if (!display.isDisposed())
					workbench.close();
			}
		});
	}
}
